@@ -25,11 +25,10 @@
 #include <sys/types.h>
 #include <gtk/gtklayout.h>
 #include <gtk/gtkbindings.h>
-#include <libgnomeprint/gnome-print.h>
-#include <libgnomeprint/gnome-print-job.h>
 
 #include "gtkhtml-types.h"
 #include "gtkhtml-enums.h"
+#include <gtk/gtk.h>
 
 /* FIXME we should remove html dep */
 #include "htmltypes.h"
@@ -103,7 +102,7 @@ struct _GtkHTMLClass {
 	gboolean (* command)              (GtkHTML *html, GtkHTMLCommandType com_type);
 	void (* cursor_changed)       (GtkHTML *html);
 	void (* object_inserted)       (GtkHTML *html, int pos, int len);
-	void (* object_deleted)        (GtkHTML *html, int pos, int len);
+	void (* object_delete)        (GtkHTML *html, int pos, int len);
 
 	/* properties */
 	GtkHTMLClassProperties *properties;
@@ -215,21 +214,19 @@ void                       gtk_html_set_animate                   (GtkHTML
 gboolean                   gtk_html_get_animate                   (const GtkHTML             *html);
 
 /* Printing support.  */
-void                       gtk_html_print_with_header_footer      (GtkHTML                   *html,
-								   GnomePrintContext         *print_context,
-								   gdouble                    header_height,
-								   gdouble                    footer_height,
+void 			   gtk_html_print_page_with_header_footer  (GtkHTML		     *html,
+								   GtkPrintContext 	     *print_context,
+			   					   gdouble		      header_height,
+								   gdouble		      footer_height,
 								   GtkHTMLPrintCallback       header_print,
-								   GtkHTMLPrintCallback       footer_print,
-								   gpointer                   user_data);
-void                       gtk_html_print                         (GtkHTML                   *html,
-								   GnomePrintContext         *print_context);
-gint                       gtk_html_print_get_pages_num           (GtkHTML                   *html,
-								   GnomePrintContext         *print_context,
-								   gdouble                    header_height,
-								   gdouble                    footer_height);
-void                       gtk_html_print_set_master              (GtkHTML                   *html,
-								   GnomePrintJob             *print_master);
+							           GtkHTMLPrintCallback       footer_print,
+								   gpointer 		      user_data);
+void			   gtk_html_print_page			   (GtkHTML		      *html,
+								    GtkPrintContext	      *print_context);
+gint 			   gtk_html_print_page_get_pages_num 	  (GtkHTML		      *html,
+								   GtkPrintContext            *print_context,
+					 			   gdouble		       header_height,
+								   gdouble                     footer_height);
 
 /* Title.  */
 const gchar               *gtk_html_get_title                     (GtkHTML                   *html);
